@@ -21,7 +21,6 @@
 	#attr(x, "HEADER") <- "some random numbers";
 	#BasicHTML(HTMLobjects = list("Fig1.png", x, "Fig2.png"), Captions=c("Gaussian noise","Gaussian and uniform random numbers", "seq 1:10"), file = paste(Sys.getenv("HOME"), "/public_html/tmp/tmp.html",sep=""), JSCPATH = "../jsc")
 	
-  require(R2HTML);
   HTMLInsertGraph <- function (GraphFileName = "", Caption = "", GraphBorder = 1, 
     Align = "center", WidthHTML = 500, HeightHTML = NULL, file = get(".HTML.file"), 
     append = TRUE, href = NULL, ...) 
@@ -107,9 +106,13 @@
   if (LaunchPage) system(paste("open ", file))
 ### no return value
 }, ex=function(){
-  if (0) {
+  if (interactive()){  
   owd=setwd(tempdir())
-  BasicHTML(cmds = list("plot(rnorm(100));","plot(1:10);"), HTMLobjects = list("Fig1.png", "Fig2.png"), Captions=c("Gaussian noise","seq 1:10"),  MenuLabels = c("Marvel at the graph below","scatterplots are nice"), title="Test Page",width=480, height=480, verbose=1, JSCPATH = NULL)
+  BasicHTML(cmds = list("plot(rnorm(100));","plot(1:10);"), 
+            HTMLobjects = list("Fig1.png", "Fig2.png"), 
+            Captions=c("Gaussian noise","seq 1:10"),  
+            MenuLabels = c("Marvel at the graph below","scatterplots are nice"), 
+            title="Test Page",width=480, height=480, verbose=1, JSCPATH = NULL)
                       
     #example with plots and graphfiles having been generated beforehand:
     png("Fig1.png");
@@ -119,9 +122,11 @@
       plot(1:10);
     dev.off();
     
-    BasicHTML( HTMLobjects = list("Fig1.png", "Fig2.png"), Captions=c("Gaussian noise","seq 1:10"), 
-               MenuLabels = c("Marvel at the graph below","scatterplots are nice"), title="Test Page",
-               width=480, height=480, verbose=1, JSCPATH = NULL);
+BasicHTML( HTMLobjects = list("Fig1.png", "Fig2.png"), 
+  Captions=c("Gaussian noise","seq 1:10"), 
+   MenuLabels = c("Marvel at the graph below","scatterplots are nice"), 
+  title="Test Page",
+  width=480, height=480, verbose=1, JSCPATH = NULL);
     
     #example with absolute paths for graphfiles :
     Fig1 <- paste(tempdir(),"/Fig1.png",sep="")
@@ -133,9 +138,10 @@
       plot(1:10);
     dev.off();
     
-    BasicHTML( HTMLobjects = list(Fig1, Fig2), Captions=c("Gaussian noise","seq 1:10"),  
-               MenuLabels = c("Marvel at the graph below","scatterplots are nice"), title="Test Page",
-               width=480, height=480, verbose=1, JSCPATH = NULL);
+BasicHTML( HTMLobjects = list(Fig1, Fig2), 
+    Captions=c("Gaussian noise","seq 1:10"),  
+    MenuLabels = c("Marvel at the graph below","scatterplots are nice"), title="Test Page",
+    width=480, height=480, verbose=1, JSCPATH = NULL);
     #cleanup:
     #system(paste("rm ", Fig1));system(paste("rm ", Fig2))
 
@@ -143,8 +149,9 @@
   x <- cbind.data.frame(x1 = round(rnorm(10),3), x2 = round(runif(10),3));
   attr(x, "HEADER") <- "some random numbers";
   BasicHTML(HTMLobjects = list("Fig1.png", x, "Fig2.png"), 
-                     Captions=c("Gaussian noise","Gaussian and uniform random numbers", "seq 1:10"), 
-                     file = paste(Sys.getenv("HOME"), "/public_html/tmp/tmp.html",sep=""), JSCPATH = "../jsc");
+            Captions=c("Gaussian noise","Gaussian and uniform random numbers", "seq 1:10"), 
+            file = paste(Sys.getenv("HOME"), "/public_html/tmp/tmp.html",sep=""), 
+            JSCPATH = "../jsc");
   setwd(owd)
-  }
+}
 })
